==> apache-camel-3.16.0-src.zip: apache-camel-3.16.0/dsl/camel-dsl-modeline/src/main/java/org/apache/camel/dsl/modeline/EnvTrait.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.dsl.modeline;

import org.apache.camel.CamelContext;
import org.apache.camel.spi.CamelContextCustomizer;
import org.apache.camel.util.StringHelper;

public class EnvTrait implements Trait {

    @Override
    public String getName() {
        return "env";
    }

    @Override
    public CamelContextCustomizer parseTrait(String trait) {
        String key = StringHelper.before(trait, "=").trim();
        String value = StringHelper.after(trait, "=").trim();
        return new CamelContextCustomizer() {
            @Override
            public void configure(CamelContext camelContext) {
                System.getenv().put(key, value);
            }
        };
    }

}

==> apache-camel-4.8.9-src.zip: apache-camel-4.8.9/dsl/camel-dsl-modeline/src/main/java/org/apache/camel/dsl/modeline/EnvTrait.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.dsl.modeline;

import org.apache.camel.CamelContext;
import org.apache.camel.spi.CamelContextCustomizer;
import org.apache.camel.spi.Resource;
import org.apache.camel.util.StringHelper;

public class EnvTrait implements Trait {

    @Override
    public String getName() {
        return "env";
    }

    @Override
    public CamelContextCustomizer parseTrait(Resource resource, String trait) {
        String key = StringHelper.before(trait, "=").trim();
        String value = StringHelper.after(trait, "=").trim();
        return new CamelContextCustomizer() {
            @Override
            public void configure(CamelContext camelContext) {
                System.getenv().put(key, value);
            }
        };
    }

}
